@@ -9,6 +9,7 @@
 
 #include "ui_editor.h"
 #include <fcitxqtconfiguiwidget.h>
+#include <memory>
 
 class CMacroTable;
 
@@ -39,7 +40,7 @@ private slots:
     void exportFileSelected();
 
 private:
-    CMacroTable *table_;
+    std::unique_ptr<CMacroTable> table_;
     MacroModel *model_;
 };
 } // namespace unikey
